@@ -12,27 +12,34 @@ from mns_common.db.MongodbUtil import MongodbUtil
 import mns_common.component.common_service_fun_api as common_service_fun_api
 import mns_common.constant.db_name_constant as db_name_constant
 import mns_common.api.xueqiu.xue_qiu_k_line_api as xue_qiu_k_line_api
+import mns_common.component.cookie.cookie_info_service as cookie_info_service
+from datetime import datetime
+import mns_common.utils.data_frame_util as data_frame_util
 
 mongodb_util = MongodbUtil('27017')
 
 
 def sync_year_k_line():
-    global symbol_prefix
+    timestamp = str(int(datetime.now().timestamp() * 1000))
+
     col_name = db_name_constant.STOCK_QFQ_YEAR
     real_time_quotes_all_stocks_df = em_stock_info_api.get_a_stock_info()
     real_time_quotes_all_stocks_df = common_service_fun_api.classify_symbol(real_time_quotes_all_stocks_df)
+    real_time_quotes_all_stocks_df = common_service_fun_api.add_pre_prefix(real_time_quotes_all_stocks_df)
     for stock_one in real_time_quotes_all_stocks_df.itertuples():
         symbol = stock_one.symbol
         try:
-            classification = stock_one.classification
-            if classification in ['H', 'K']:
-                symbol_prefix = 'SH' + symbol
-            elif classification in ['S', 'C']:
-                symbol_prefix = 'SZ' + symbol
-            elif classification in ['X']:
-                symbol_prefix = 'BJ' + symbol
+            symbol_prefix = stock_one.symbol_prefix
 
-            year_k_line_df = xue_qiu_k_line_api.get_xue_qiu_k_line(symbol_prefix, 'year')
+            year_k_line_df_copy = xue_qiu_k_line_api.get_xue_qiu_k_line(symbol_prefix, 'year',
+                                                                        cookie_info_service.get_xue_qiu_cookie(),
+                                                                        timestamp,
+                                                                        'before')
+            if data_frame_util.is_empty(year_k_line_df_copy):
+                logger.warning("返回数据为空:{}", symbol)
+                continue
+
+            year_k_line_df = year_k_line_df_copy.copy()
             year_k_line_df = year_k_line_df[[
                 'volume',
                 'open',
