@@ -51,6 +51,9 @@ def update_symbol_new_concept_reason(plate_code, kpl_symbol_list):
     symbol_str = ','.join(kpl_symbol_list)
     choose_reason_df = kpl_common_api.get_kpl_concept_choose_reason(plate_code, symbol_str)
     if data_frame_util.is_not_empty(choose_reason_df):
+        choose_reason_df = choose_reason_df[choose_reason_df['choose_reason'] != '']
+        if data_frame_util.is_empty(choose_reason_df):
+            return
         for choose_reason_one in choose_reason_df.itertuples():
             symbol = choose_reason_one.symbol
             try:
