@@ -8,11 +8,10 @@ sys.path.append(project_path)
 import mns_common.api.ths.self_choose.ths_self_choose_api as ths_self_choose_api
 import mns_common.constant.db_name_constant as db_name_constant
 from mns_common.db.MongodbUtil import MongodbUtil
-import mns_common.api.ths.zt.ths_stock_zt_pool_api as ths_stock_zt_pool_api
+import mns_common.component.cookie.cookie_info_service as cookie_info_service
 import mns_common.component.common_service_fun_api as common_service_fun_api
 from datetime import datetime
 import mns_common.utils.data_frame_util as data_frame_util
-from functools import lru_cache
 import mns_common.constant.self_choose_constant as self_choose_constant
 import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
 
@@ -41,22 +40,17 @@ mongodb_util = MongodbUtil('27017')
 fixed_optional_list = ['899050', '881157']
 
 
-@lru_cache()
-def get_ths_cookie():
-    query = {"type": "ths_cookie"}
-    stock_account_info = mongodb_util.find_query_data(db_name_constant.STOCK_ACCOUNT_INFO, query)
-    ths_cookie = list(stock_account_info['cookie'])[0]
-    return ths_cookie
+
 
 
 def add_fixed_optional():
-    ths_cookie = get_ths_cookie()
+    ths_cookie = cookie_info_service.get_ths_cookie()
     for symbol in fixed_optional_list:
         ths_self_choose_api.add_stock_to_account(symbol, ths_cookie)
 
 
 def delete_all_self_choose_stocks():
-    ths_cookie = get_ths_cookie()
+    ths_cookie =  cookie_info_service.get_ths_cookie()
     all_self_choose_stock_list = ths_self_choose_api.get_all_self_choose_stock_list(ths_cookie)
     for stock_one in all_self_choose_stock_list.itertuples():
         symbol = stock_one.code
@@ -64,7 +58,7 @@ def delete_all_self_choose_stocks():
 
 
 def add_self_choose_local():
-    ths_cookie = get_ths_cookie()
+    ths_cookie =  cookie_info_service.get_ths_cookie()
     # 固定自选
     self_choose_symbol_df = mongodb_util.find_all_data(db_name_constant.SELF_CHOOSE_STOCK)
     if data_frame_util.is_not_empty(self_choose_symbol_df):
@@ -109,7 +103,7 @@ def add_trade_stocks():
     trade_stocks_df = mongodb_util.find_query_data(db_name_constant.BUY_STOCK_NAME, query)
     if data_frame_util.is_not_empty(trade_stocks_df):
         stock_list = stock_list.union(set(trade_stocks_df['symbol']))
-    ths_cookie = get_ths_cookie()
+    ths_cookie =  cookie_info_service.get_ths_cookie()
     if len(stock_list) > 0:
         for symbol in stock_list:
             ths_self_choose_api.add_stock_to_account(symbol, ths_cookie)
@@ -117,7 +111,7 @@ def add_trade_stocks():
 
 # 添加连板到自选
 def add_continue_boards_zt_stocks():
-    ths_cookie = get_ths_cookie()
+    ths_cookie =  cookie_info_service.get_ths_cookie()
     now_date = datetime.now()
     str_day = now_date.strftime('%Y-%m-%d')
     if trade_date_common_service_api.is_trade_day(str_day):
