@@ -19,13 +19,14 @@ def sync_now_day_high_chg():
     real_time_quotes_now_es = em_stock_info_api.get_a_stock_info()
     real_time_quotes_now_es_high_chg = real_time_quotes_now_es.loc[
         real_time_quotes_now_es['chg'] > common_service_fun_api.ZT_CHG]
-    # 同步qfq k线
-    daily_week_month_line_sync.sync_all_daily_data('daily', 'qfq', 'stock_qfq_daily', None,
-                                                   list(real_time_quotes_now_es_high_chg['symbol']))
-
     now_date = datetime.now()
 
     str_now_day = now_date.strftime('%Y-%m-%d')
+    # 同步qfq k线
+    daily_week_month_line_sync.sync_all_daily_data('daily', 'qfq', 'stock_qfq_daily', str_now_day,
+                                                   list(real_time_quotes_now_es_high_chg['symbol']))
+
+
     # 同步当前涨停
     em_zt_pool_sync_api.save_zt_info(str_now_day)
 
